# OhlcvAnalyser

## Current Repository Structure

```
OhlcvAnalyser
├── __init__.py
├── MultiOhlcvAnalyser.py
├── SingleOhlcvAnalyser.py
└── utils
    ├── __init__.py
    ├── coefficient.py
    ├── date.py
    └── profit.py
```

## BluePrint Repository Structure

```
OhlcvAnalyser
├── __init__.py
├── MultiOhlcvAnalyser.py
├── SingleOhlcvAnalyser.py
├── Analyser
│   ├── CoefficientAnalyser.py
│   ├── ProfitAnalyser.py
│   └── PriceAnalyser.py
└── utils
```